﻿using System;
using System.IO;
using System.Threading.Tasks;
using PuppeteerSharp;
using PuppeteerSharp.Media;


var browser = await Puppeteer.LaunchAsync(new LaunchOptions
{
    Headless = true,
    ExecutablePath = @"C:\Program Files (x86)\Microsoft\Edge\Application\msedge.exe"
});


var page = await browser.NewPageAsync();
var templatePath = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "RechnungTemplate.html");

//sicherstellen, dass die Seite vollständig geladen wurde
WaitUntilNavigation[] arg = { WaitUntilNavigation.Networkidle0, WaitUntilNavigation.Load };
await page.GoToAsync(templatePath, waitUntil: arg);
await ReplaceMarker("name", "Michael Meyer");
await ReplaceMarker("strasseHausnummer", "Maximiliansstraße 1");
await ReplaceMarker("plzOrt", "80434 München");
await RemoveMarker("mahnung");

PdfOptions pdfOptions = new()
{
    Format = PaperFormat.A4,
    MarginOptions = new() { Top = "20mm", Bottom = "20mm", Left = "14mm", Right = "14mm" },
    DisplayHeaderFooter = true,
    HeaderTemplate = "<span />",
    FooterTemplate = "<div style=\"font-size:10px; margin: 0 14mm; text-align: right;\">Seite <span class=\"pageNumber\"></span> von <span class=\"totalPages\"></span></div>",
};

await page.PdfAsync(@"c:\temp\Rechnung.pdf", pdfOptions);

async Task ReplaceMarker(string markerId, string content)
{
    var jSQuery = @$"document.getElementById(""{markerId}"").innerHTML = ""{content}""";
    await page.EvaluateExpressionAsync(jSQuery);
}

async Task RemoveMarker(string markerId)
{
    var jSQuery = @$"var element = document.getElementById(""{markerId}"");" +
                  "element.remove();";
    await page.EvaluateExpressionAsync(jSQuery);
}