﻿using System;
using System.Collections.Generic;
using System.IO;
using HtmlAgilityPack;
using HtmlPdfGenerator;
using PuppeteerSharp;

var browser = await Puppeteer.LaunchAsync(new LaunchOptions
{
    Headless = true,
    ExecutablePath = @"C:\Program Files (x86)\Microsoft\Edge\Application\msedge.exe",
    Args = new[] { "--disable-web-security" }, // wichtig um Javascript lokal auszuführen
});


var page = await browser.NewPageAsync();
var templatePath = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, @"template\RechnungTemplate.html");

List<Replacement> replaceValues = new()
{
    new("name", "Michael Meyer", false),
    new("strasseHausnummer", "Maximiliansstraße 1", false),
    new("plzOrt", "80434 München", false),
    new("mahnung", null, true),
    new("sonderaktion", "Nur im Mai. 20 % Rabatt auf alles!", false),
};


var tempFile = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, @"template\Rechnung_temp.html");
ReplaceMarkers(templatePath, tempFile, replaceValues);

PdfOptions pdfOptions = new()
{
    PreferCSSPageSize = true,
    PrintBackground = true,
    DisplayHeaderFooter = false,
};

WaitUntilNavigation[] arg = { WaitUntilNavigation.Networkidle0, WaitUntilNavigation.Load };
await page.GoToAsync(tempFile, waitUntil: arg);
await page.PdfAsync(@"c:\temp\Rechnung.pdf", pdfOptions);


void ReplaceMarkers(string templateFilePath, string tempFilePath, IEnumerable<Replacement> replacements)
{
    var htmlDoc = new HtmlDocument();
    htmlDoc.Load(templateFilePath);

    foreach (var replacement in replacements)
    {
        var id = replacement.Id;
        var node = htmlDoc.DocumentNode.SelectSingleNode($"//*[@id='{id}']");
        if (node == null)
        {
            continue; // alterantiv: ErrorHandling
        }

        if (replacement.RemoveElement)
        {
            node.Remove();
        }
        else
        {
            node.InnerHtml = replacement.InsertValue;
        }
    }

    htmlDoc.Save(tempFilePath);
}



